package javax.swing;

import java.awt.image.FilteredImageSource;
import java.awt.image.ImageObserver;
import java.text.AttributedCharacterIterator;
import java.awt.Toolkit;
import java.awt.Shape;
import java.awt.Rectangle;
import java.awt.Point;
import java.awt.FontMetrics;
import java.awt.Font;
import java.io.PrintStream;
import java.awt.Color;
import java.awt.Image;
import java.awt.Graphics;

public class DebugGraphics extends Graphics
{
    Graphics graphics;
    Image buffer;
    int debugOptions;
    int graphicsID;
    int xOffset;
    int yOffset;
    private static int graphicsCount;
    private static ImageIcon imageLoadingIcon;
    public static final int LOG_OPTION = 1;
    public static final int FLASH_OPTION = 2;
    public static final int BUFFERED_OPTION = 4;
    public static final int NONE_OPTION = -1;
    private static final Class debugGraphicsInfoKey;
    
    public DebugGraphics() {
        this.graphicsID = DebugGraphics.graphicsCount++;
        this.buffer = null;
        int n = 0;
        this.yOffset = n;
        this.xOffset = n;
    }
    
    public DebugGraphics(Graphics graphics, JComponent component) {
        this(graphics);
        this.setDebugOptions(component.shouldDebugGraphics());
    }
    
    public DebugGraphics(Graphics graphics) {
        this();
        this.graphics = graphics;
    }
    
    @Override
    public Graphics create() {
        DebugGraphics debugGraphics = new DebugGraphics();
        debugGraphics.graphics = this.graphics.create();
        debugGraphics.debugOptions = this.debugOptions;
        debugGraphics.buffer = this.buffer;
        return debugGraphics;
    }
    
    @Override
    public Graphics create(int x, int y, int width, int height) {
        DebugGraphics debugGraphics = new DebugGraphics();
        debugGraphics.graphics = this.graphics.create(x, y, width, height);
        debugGraphics.debugOptions = this.debugOptions;
        debugGraphics.buffer = this.buffer;
        debugGraphics.xOffset = this.xOffset + x;
        debugGraphics.yOffset = this.yOffset + y;
        return debugGraphics;
    }
    
    public static void setFlashColor(Color flashColor) {
        info().flashColor = flashColor;
    }
    
    public static Color flashColor() {
        return info().flashColor;
    }
    
    public static void setFlashTime(int flashTime) {
        info().flashTime = flashTime;
    }
    
    public static int flashTime() {
        return info().flashTime;
    }
    
    public static void setFlashCount(int flashCount) {
        info().flashCount = flashCount;
    }
    
    public static int flashCount() {
        return info().flashCount;
    }
    
    public static void setLogStream(PrintStream stream) {
        info().stream = stream;
    }
    
    public static PrintStream logStream() {
        return info().stream;
    }
    
    @Override
    public void setFont(Font font) {
        if (this.debugLog()) {
            info().log(this.toShortString() + " Setting font: " + font);
        }
        this.graphics.setFont(font);
    }
    
    @Override
    public Font getFont() {
        return this.graphics.getFont();
    }
    
    @Override
    public void setColor(Color color) {
        if (this.debugLog()) {
            info().log(this.toShortString() + " Setting color: " + color);
        }
        this.graphics.setColor(color);
    }
    
    @Override
    public Color getColor() {
        return this.graphics.getColor();
    }
    
    @Override
    public FontMetrics getFontMetrics() {
        return this.graphics.getFontMetrics();
    }
    
    @Override
    public FontMetrics getFontMetrics(Font font) {
        return this.graphics.getFontMetrics(font);
    }
    
    @Override
    public void translate(int x, int y) {
        if (this.debugLog()) {
            info().log(this.toShortString() + " Translating by: " + new Point(x, y));
        }
        this.xOffset += x;
        this.yOffset += y;
        this.graphics.translate(x, y);
    }
    
    @Override
    public void setPaintMode() {
        if (this.debugLog()) {
            info().log(this.toShortString() + " Setting paint mode");
        }
        this.graphics.setPaintMode();
    }
    
    @Override
    public void setXORMode(Color color) {
        if (this.debugLog()) {
            info().log(this.toShortString() + " Setting XOR mode: " + color);
        }
        this.graphics.setXORMode(color);
    }
    
    @Override
    public Rectangle getClipBounds() {
        return this.graphics.getClipBounds();
    }
    
    @Override
    public void clipRect(int x, int y, int width, int height) {
        this.graphics.clipRect(x, y, width, height);
        if (this.debugLog()) {
            info().log(this.toShortString() + " Setting clipRect: " + new Rectangle(x, y, width, height) + " New clipRect: " + this.graphics.getClip());
        }
    }
    
    @Override
    public void setClip(int n, int n2, int n3, int n4) {
        this.graphics.setClip(n, n2, n3, n4);
        if (this.debugLog()) {
            info().log(this.toShortString() + " Setting new clipRect: " + this.graphics.getClip());
        }
    }
    
    @Override
    public Shape getClip() {
        return this.graphics.getClip();
    }
    
    @Override
    public void setClip(Shape clip) {
        this.graphics.setClip(clip);
        if (this.debugLog()) {
            info().log(this.toShortString() + " Setting new clipRect: " + this.graphics.getClip());
        }
    }
    
    @Override
    public void drawRect(int n, int n2, int n3, int n4) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing rect: " + new Rectangle(n, n2, n3, n4));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawRect(n, n2, n3, n4);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n5 = info.flashCount * 2 - 1, i = 0; i < n5; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.drawRect(n, n2, n3, n4);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawRect(n, n2, n3, n4);
    }
    
    @Override
    public void fillRect(int x, int y, int width, int height) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Filling rect: " + new Rectangle(x, y, width, height));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.fillRect(x, y, width, height);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, i = 0; i < n; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.fillRect(x, y, width, height);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.fillRect(x, y, width, height);
    }
    
    @Override
    public void clearRect(int x, int y, int width, int height) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Clearing rect: " + new Rectangle(x, y, width, height));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.clearRect(x, y, width, height);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, i = 0; i < n; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.clearRect(x, y, width, height);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.clearRect(x, y, width, height);
    }
    
    @Override
    public void drawRoundRect(int x, int y, int width, int height, int i, int j) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing round rect: " + new Rectangle(x, y, width, height) + " arcWidth: " + i + " archHeight: " + j);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawRoundRect(x, y, width, height, i, j);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, k = 0; k < n; ++k) {
                this.graphics.setColor((k % 2 == 0) ? info.flashColor : color);
                this.graphics.drawRoundRect(x, y, width, height, i, j);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawRoundRect(x, y, width, height, i, j);
    }
    
    @Override
    public void fillRoundRect(int x, int y, int width, int height, int i, int j) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Filling round rect: " + new Rectangle(x, y, width, height) + " arcWidth: " + i + " archHeight: " + j);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.fillRoundRect(x, y, width, height, i, j);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, k = 0; k < n; ++k) {
                this.graphics.setColor((k % 2 == 0) ? info.flashColor : color);
                this.graphics.fillRoundRect(x, y, width, height, i, j);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.fillRoundRect(x, y, width, height, i, j);
    }
    
    @Override
    public void drawLine(int n, int n2, int n3, int n4) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing line: from " + this.pointToString(n, n2) + " to " + this.pointToString(n3, n4));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawLine(n, n2, n3, n4);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n5 = info.flashCount * 2 - 1, i = 0; i < n5; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.drawLine(n, n2, n3, n4);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawLine(n, n2, n3, n4);
    }
    
    @Override
    public void draw3DRect(int n, int n2, int n3, int n4, boolean b) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing 3D rect: " + new Rectangle(n, n2, n3, n4) + " Raised bezel: " + b);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.draw3DRect(n, n2, n3, n4, b);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n5 = info.flashCount * 2 - 1, i = 0; i < n5; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.draw3DRect(n, n2, n3, n4, b);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.draw3DRect(n, n2, n3, n4, b);
    }
    
    @Override
    public void fill3DRect(int n, int n2, int n3, int n4, boolean b) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Filling 3D rect: " + new Rectangle(n, n2, n3, n4) + " Raised bezel: " + b);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.fill3DRect(n, n2, n3, n4, b);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n5 = info.flashCount * 2 - 1, i = 0; i < n5; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.fill3DRect(n, n2, n3, n4, b);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.fill3DRect(n, n2, n3, n4, b);
    }
    
    @Override
    public void drawOval(int x, int y, int width, int height) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing oval: " + new Rectangle(x, y, width, height));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawOval(x, y, width, height);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, i = 0; i < n; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.drawOval(x, y, width, height);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawOval(x, y, width, height);
    }
    
    @Override
    public void fillOval(int x, int y, int width, int height) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Filling oval: " + new Rectangle(x, y, width, height));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.fillOval(x, y, width, height);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, i = 0; i < n; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.fillOval(x, y, width, height);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.fillOval(x, y, width, height);
    }
    
    @Override
    public void drawArc(int x, int y, int width, int height, int i, int j) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing arc: " + new Rectangle(x, y, width, height) + " startAngle: " + i + " arcAngle: " + j);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawArc(x, y, width, height, i, j);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, k = 0; k < n; ++k) {
                this.graphics.setColor((k % 2 == 0) ? info.flashColor : color);
                this.graphics.drawArc(x, y, width, height, i, j);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawArc(x, y, width, height, i, j);
    }
    
    @Override
    public void fillArc(int x, int y, int width, int height, int i, int j) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Filling arc: " + new Rectangle(x, y, width, height) + " startAngle: " + i + " arcAngle: " + j);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.fillArc(x, y, width, height, i, j);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, k = 0; k < n; ++k) {
                this.graphics.setColor((k % 2 == 0) ? info.flashColor : color);
                this.graphics.fillArc(x, y, width, height, i, j);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.fillArc(x, y, width, height, i, j);
    }
    
    @Override
    public void drawPolyline(int[] obj, int[] obj2, int i) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing polyline:  nPoints: " + i + " X's: " + obj + " Y's: " + obj2);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawPolyline(obj, obj2, i);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, j = 0; j < n; ++j) {
                this.graphics.setColor((j % 2 == 0) ? info.flashColor : color);
                this.graphics.drawPolyline(obj, obj2, i);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawPolyline(obj, obj2, i);
    }
    
    @Override
    public void drawPolygon(int[] obj, int[] obj2, int i) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing polygon:  nPoints: " + i + " X's: " + obj + " Y's: " + obj2);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawPolygon(obj, obj2, i);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, j = 0; j < n; ++j) {
                this.graphics.setColor((j % 2 == 0) ? info.flashColor : color);
                this.graphics.drawPolygon(obj, obj2, i);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawPolygon(obj, obj2, i);
    }
    
    @Override
    public void fillPolygon(int[] obj, int[] obj2, int i) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Filling polygon:  nPoints: " + i + " X's: " + obj + " Y's: " + obj2);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.fillPolygon(obj, obj2, i);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, j = 0; j < n; ++j) {
                this.graphics.setColor((j % 2 == 0) ? info.flashColor : color);
                this.graphics.fillPolygon(obj, obj2, i);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.fillPolygon(obj, obj2, i);
    }
    
    @Override
    public void drawString(String str, int x, int y) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing string: \"" + str + "\" at: " + new Point(x, y));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawString(str, x, y);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, i = 0; i < n; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.drawString(str, x, y);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawString(str, x, y);
    }
    
    @Override
    public void drawString(AttributedCharacterIterator obj, int x, int y) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing text: \"" + obj + "\" at: " + new Point(x, y));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawString(obj, x, y);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n = info.flashCount * 2 - 1, i = 0; i < n; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.drawString(obj, x, y);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawString(obj, x, y);
    }
    
    @Override
    public void drawBytes(byte[] data, int offset, int length, int n, int n2) {
        DebugGraphicsInfo info = info();
        this.graphics.getFont();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing bytes at: " + new Point(n, n2));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawBytes(data, offset, length, n, n2);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n3 = info.flashCount * 2 - 1, i = 0; i < n3; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.drawBytes(data, offset, length, n, n2);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawBytes(data, offset, length, n, n2);
    }
    
    @Override
    public void drawChars(char[] data, int offset, int length, int n, int n2) {
        DebugGraphicsInfo info = info();
        this.graphics.getFont();
        if (this.debugLog()) {
            info().log(this.toShortString() + " Drawing chars at " + new Point(n, n2));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawChars(data, offset, length, n, n2);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            Color color = this.getColor();
            for (int n3 = info.flashCount * 2 - 1, i = 0; i < n3; ++i) {
                this.graphics.setColor((i % 2 == 0) ? info.flashColor : color);
                this.graphics.drawChars(data, offset, length, n, n2);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
            this.graphics.setColor(color);
        }
        this.graphics.drawChars(data, offset, length, n, n2);
    }
    
    @Override
    public boolean drawImage(Image obj, int x, int y, ImageObserver imageObserver) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info.log(this.toShortString() + " Drawing image: " + obj + " at: " + new Point(x, y));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawImage(obj, x, y, imageObserver);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            int n = info.flashCount * 2 - 1;
            Image image = Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(obj.getSource(), new DebugGraphicsFilter(info.flashColor)));
            DebugGraphicsObserver debugGraphicsObserver = new DebugGraphicsObserver();
            for (int i = 0; i < n; ++i) {
                obj = ((i % 2 == 0) ? image : obj);
                loadImage(obj);
                this.graphics.drawImage(obj, x, y, debugGraphicsObserver);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
        }
        return this.graphics.drawImage(obj, x, y, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image obj, int x, int y, int width, int height, ImageObserver imageObserver) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info.log(this.toShortString() + " Drawing image: " + obj + " at: " + new Rectangle(x, y, width, height));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawImage(obj, x, y, width, height, imageObserver);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            int n = info.flashCount * 2 - 1;
            Image image = Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(obj.getSource(), new DebugGraphicsFilter(info.flashColor)));
            DebugGraphicsObserver debugGraphicsObserver = new DebugGraphicsObserver();
            for (int i = 0; i < n; ++i) {
                obj = ((i % 2 == 0) ? image : obj);
                loadImage(obj);
                this.graphics.drawImage(obj, x, y, width, height, debugGraphicsObserver);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
        }
        return this.graphics.drawImage(obj, x, y, width, height, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image obj, int x, int y, Color obj2, ImageObserver imageObserver) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info.log(this.toShortString() + " Drawing image: " + obj + " at: " + new Point(x, y) + ", bgcolor: " + obj2);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawImage(obj, x, y, obj2, imageObserver);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            int n = info.flashCount * 2 - 1;
            Image image = Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(obj.getSource(), new DebugGraphicsFilter(info.flashColor)));
            DebugGraphicsObserver debugGraphicsObserver = new DebugGraphicsObserver();
            for (int i = 0; i < n; ++i) {
                obj = ((i % 2 == 0) ? image : obj);
                loadImage(obj);
                this.graphics.drawImage(obj, x, y, obj2, debugGraphicsObserver);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
        }
        return this.graphics.drawImage(obj, x, y, obj2, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image obj, int x, int y, int width, int height, Color obj2, ImageObserver imageObserver) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info.log(this.toShortString() + " Drawing image: " + obj + " at: " + new Rectangle(x, y, width, height) + ", bgcolor: " + obj2);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawImage(obj, x, y, width, height, obj2, imageObserver);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            int n = info.flashCount * 2 - 1;
            Image image = Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(obj.getSource(), new DebugGraphicsFilter(info.flashColor)));
            DebugGraphicsObserver debugGraphicsObserver = new DebugGraphicsObserver();
            for (int i = 0; i < n; ++i) {
                obj = ((i % 2 == 0) ? image : obj);
                loadImage(obj);
                this.graphics.drawImage(obj, x, y, width, height, obj2, debugGraphicsObserver);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
        }
        return this.graphics.drawImage(obj, x, y, width, height, obj2, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image obj, int x, int y, int width, int height, int x2, int y2, int width2, int height2, ImageObserver imageObserver) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info.log(this.toShortString() + " Drawing image: " + obj + " destination: " + new Rectangle(x, y, width, height) + " source: " + new Rectangle(x2, y2, width2, height2));
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawImage(obj, x, y, width, height, x2, y2, width2, height2, imageObserver);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            int n = info.flashCount * 2 - 1;
            Image image = Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(obj.getSource(), new DebugGraphicsFilter(info.flashColor)));
            DebugGraphicsObserver debugGraphicsObserver = new DebugGraphicsObserver();
            for (int i = 0; i < n; ++i) {
                obj = ((i % 2 == 0) ? image : obj);
                loadImage(obj);
                this.graphics.drawImage(obj, x, y, width, height, x2, y2, width2, height2, debugGraphicsObserver);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
        }
        return this.graphics.drawImage(obj, x, y, width, height, x2, y2, width2, height2, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image obj, int x, int y, int width, int height, int x2, int y2, int width2, int height2, Color obj2, ImageObserver imageObserver) {
        DebugGraphicsInfo info = info();
        if (this.debugLog()) {
            info.log(this.toShortString() + " Drawing image: " + obj + " destination: " + new Rectangle(x, y, width, height) + " source: " + new Rectangle(x2, y2, width2, height2) + ", bgcolor: " + obj2);
        }
        if (this.isDrawingBuffer()) {
            if (this.debugBuffered()) {
                Graphics debugGraphics = this.debugGraphics();
                debugGraphics.drawImage(obj, x, y, width, height, x2, y2, width2, height2, obj2, imageObserver);
                debugGraphics.dispose();
            }
        }
        else if (this.debugFlash()) {
            int n = info.flashCount * 2 - 1;
            Image image = Toolkit.getDefaultToolkit().createImage(new FilteredImageSource(obj.getSource(), new DebugGraphicsFilter(info.flashColor)));
            DebugGraphicsObserver debugGraphicsObserver = new DebugGraphicsObserver();
            for (int i = 0; i < n; ++i) {
                obj = ((i % 2 == 0) ? image : obj);
                loadImage(obj);
                this.graphics.drawImage(obj, x, y, width, height, x2, y2, width2, height2, obj2, debugGraphicsObserver);
                Toolkit.getDefaultToolkit().sync();
                this.sleep(info.flashTime);
            }
        }
        return this.graphics.drawImage(obj, x, y, width, height, x2, y2, width2, height2, obj2, imageObserver);
    }
    
    static void loadImage(Image image) {
        DebugGraphics.imageLoadingIcon.loadImage(image);
    }
    
    @Override
    public void copyArea(int x, int y, int width, int height, int x2, int y2) {
        if (this.debugLog()) {
            info().log(this.toShortString() + " Copying area from: " + new Rectangle(x, y, width, height) + " to: " + new Point(x2, y2));
        }
        this.graphics.copyArea(x, y, width, height, x2, y2);
    }
    
    final void sleep(int n) {
        try {
            Thread.sleep((long)n);
        }
        catch (Exception ex) {}
    }
    
    @Override
    public void dispose() {
        this.graphics.dispose();
        this.graphics = null;
    }
    
    public boolean isDrawingBuffer() {
        return this.buffer != null;
    }
    
    String toShortString() {
        return "Graphics" + (this.isDrawingBuffer() ? "<B>" : "") + "(" + this.graphicsID + "-" + this.debugOptions + ")";
    }
    
    String pointToString(int i, int j) {
        return "(" + i + ", " + j + ")";
    }
    
    public void setDebugOptions(int n) {
        if (n != 0) {
            if (n == -1) {
                if (this.debugOptions != 0) {
                    System.err.println(this.toShortString() + " Disabling debug");
                    this.debugOptions = 0;
                }
            }
            else if (this.debugOptions != n) {
                this.debugOptions |= n;
                if (this.debugLog()) {
                    System.err.println(this.toShortString() + " Enabling debug");
                }
            }
        }
    }
    
    public int getDebugOptions() {
        return this.debugOptions;
    }
    
    static void setDebugOptions(JComponent component, int n) {
        info().setDebugOptions(component, n);
    }
    
    static int getDebugOptions(JComponent component) {
        DebugGraphicsInfo info = info();
        if (info == null) {
            return 0;
        }
        return info.getDebugOptions(component);
    }
    
    static int shouldComponentDebug(JComponent parent) {
        DebugGraphicsInfo info = info();
        if (info == null) {
            return 0;
        }
        int n = 0;
        while (parent != null && parent instanceof JComponent) {
            n |= info.getDebugOptions((JComponent)parent);
            parent = parent.getParent();
        }
        return n;
    }
    
    static int debugComponentCount() {
        DebugGraphicsInfo info = info();
        if (info != null && info.componentToDebug != null) {
            return info.componentToDebug.size();
        }
        return 0;
    }
    
    boolean debugLog() {
        return (this.debugOptions & 0x1) == 0x1;
    }
    
    boolean debugFlash() {
        return (this.debugOptions & 0x2) == 0x2;
    }
    
    boolean debugBuffered() {
        return (this.debugOptions & 0x4) == 0x4;
    }
    
    private Graphics debugGraphics() {
        DebugGraphicsInfo info = info();
        if (info.debugFrame == null) {
            (info.debugFrame = new JFrame()).setSize(500, 500);
        }
        JFrame debugFrame = info.debugFrame;
        debugFrame.show();
        DebugGraphics debugGraphics = new DebugGraphics(debugFrame.getGraphics());
        debugGraphics.setFont(this.getFont());
        debugGraphics.setColor(this.getColor());
        debugGraphics.translate(this.xOffset, this.yOffset);
        debugGraphics.setClip(this.getClipBounds());
        if (this.debugFlash()) {
            debugGraphics.setDebugOptions(2);
            return debugGraphics;
        }
        return debugGraphics;
    }
    
    static DebugGraphicsInfo info() {
        DebugGraphicsInfo debugGraphicsInfo = (DebugGraphicsInfo)SwingUtilities.appContextGet(DebugGraphics.debugGraphicsInfoKey);
        if (debugGraphicsInfo == null) {
            debugGraphicsInfo = new DebugGraphicsInfo();
            SwingUtilities.appContextPut(DebugGraphics.debugGraphicsInfoKey, debugGraphicsInfo);
            return debugGraphicsInfo;
        }
        return debugGraphicsInfo;
    }
    
    static {
        DebugGraphics.graphicsCount = 0;
        DebugGraphics.imageLoadingIcon = new ImageIcon();
        JComponent.DEBUG_GRAPHICS_LOADED = true;
        debugGraphicsInfoKey = DebugGraphicsInfo.class;
    }
}
